# Welcome to forecast-weather's documentation!

## This is a first header

- These
- are
- some
- bullets


```eval_rst
.. note::
    We can still mix rst, which we'll use for autodocumentation

.. autofunction:: forecast_weather.show_current
```